@@ -354,7 +354,7 @@ class S3:
 
 			self.write_pickle(obj=obj, path=path, mode=mode)
 
-		return self / path
+		return path
 
 	def load(self, path, spark=None):
 		"""
@@ -364,6 +364,8 @@ class S3:
 		:type spark: pyspark.sql.session.SparkSession
 		:rtype: bool
 		"""
+		path = self._get_absolute_path(path)
+
 		if path.endswith('.parquet'):
 			return self.read_parquet(path=path, spark=spark or self.spark)
 
@@ -383,6 +385,9 @@ class S3:
 			other = str(other)
 		return S3Path(s3=self, path=other)
 
+	def __add__(self, other):
+		return self.__truediv__(other)
+
 
 class S3Path:
 	def __init__(self, s3, path):
@@ -397,6 +402,10 @@ class S3Path:
 		self._s3 = s3
 		self._path = path
 
+	@property
+	def path(self):
+		return self._path
+
 	def __truediv__(self, other):
 		"""
 		:type other: str
@@ -409,7 +418,16 @@ class S3Path:
 		right = other.lstrip('/')
 		return self.__class__(s3=self.s3, path=f'{left}/{right}')
 
-	__add__ = __truediv__
+	def __add__(self, other):
+		"""
+		:type other: str
+		:rtype: S3Path
+		"""
+		if other.startswith('.'):  # other is an extension
+			left = self._path.rstrip('/')
+			return self.__class__(s3=self.s3, path=f'{left}{other}')
+		else:
+			return self.__truediv__(other)
 
 	def __repr__(self):
 		path = self._path
